# jQuery Network Error Test for Firefox

This is a test page for #8135 which was reported in Firefox when accessing properties of an XMLHttpRequest object after a network error occured.
Take the following steps:

1. make sure you accessed this page through a web server,
2. stop the web server,
3. open the console,
4. click this
   ,
5. wait for both requests to fail.

Test passes if you get two log lines:

- the first starting with "abort",
- the second starting with "complete",

Test fails if the browser notifies an exception.